
Sensitive information stored in cookies
-------

**Description:**

Sensitive data should not be stored in a cookie. 
Because the cookie is also used client-side and is adaptable and thus making 
it content readable. A hacker could gain access to a cookie through cross site scripting 
attacks and gain the sensitive information stored
in the targets cookie.


**Solution:**

Do not store sensitive information in cookies. 
	